==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/Db4oHashMapOnItsOwn.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using j4o.util;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   /**
    * 
    */
   public class Db4oHashMapOnItsOwn {
      
      public Db4oHashMapOnItsOwn() : base() {
      }

      internal Object obj;
      
      public void storeOne() {
         ExtObjectContainer oc1 = Tester.objectContainer();
         IDictionary map1 = oc1.collections().newHashMap(10);
         map1["one"] = "one";
         oc1.set(map1);
         obj = map1;
      }
      
      public void testOne() {
         IDictionary map1 = (IDictionary)obj;
         Tester.ensure(map1["one"].Equals("one"));
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/Db4oHashMapOnItsOwn.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using j4o.lang;
using j4o.util;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   /**
    * 
    */
   public class Db4oHashMapOnItsOwn {
      
      public Db4oHashMapOnItsOwn() : base() {
      }

      internal Object obj;
      
      public void StoreOne() {
         ExtObjectContainer oc1 = Tester.ObjectContainer();
         IDictionary map1 = oc1.Collections().NewHashMap(10);
         map1["one"] = "one";
         oc1.Set(map1);
         obj = map1;
      }
      
      public void TestOne() {
         IDictionary map1 = (IDictionary)obj;
         Tester.Ensure(map1["one"].Equals("one"));
      }
   }
}
